@@ -1,7 +1,7 @@
 """entity classes for entity types provided by the cubicweb email package
 
 :organization: Logilab
-:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -11,14 +11,15 @@ import re
 from logilab.common import umessage
 
 from cubicweb.entities import AnyEntity, fetch_config, adapters
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
+
 from cubes.email.emailcites import parse_body
 
 
 class Email(AnyEntity):
     """customized class for Email entities"""
     __regid__ = 'Email'
-    fetch_attrs, fetch_order = fetch_config(['subject'])
+    fetch_attrs, cw_fetch_order = fetch_config(['subject'])
 
     def dc_title(self):
         return self.subject
@@ -120,7 +121,7 @@ class EmailPart(AnyEntity):
 class EmailThread(AnyEntity):
     """customized class for EmailThread entities"""
     __regid__ = 'EmailThread'
-    fetch_attrs, fetch_order = fetch_config(['title'])
+    fetch_attrs, cw_fetch_order = fetch_config(['title'])
 
     def dc_title(self):
         return self.title
