@@ -1,12 +1,17 @@
 """import an mbox or a single email into an cubicweb application
 
 :organization: Logilab
-:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
 
 import re
+import mailbox
+from itertools import combinations
+from rfc822 import parsedate
+
+from logilab.common.umessage import message_from_file
 
 from cubicweb import Binary
 
@@ -14,24 +19,22 @@ CLEANUP_RGX = re.compile(r'\bre\s*:', re.I|re.U)
 def cleanup_subject(string):
     return CLEANUP_RGX.sub('', string).strip()
 
-def combinaison(list):
-    """given a list return an iterator on possible combinaisons between all the
-    elements in the list but without identity:
 
-    >>> list(combinaison([1,2,3]))
-    [(1, 2), (2, 3), (1, 3)]
-    >>> list(combinaison([1,2,3,4]))
-    [(1, 2), (2, 3), (3, 4), (1,3), (1,4), (2,4)]
+class StreamMailbox(mailbox.mbox):
+    """A read-only mbox format mailbox from stream."""
+    _mangle_from_ = True
+
+    def __init__(self, stream, factory=None, create=True):
+        """Initialize a stream mailbox."""
+        self._message_factory = mailbox.mboxMessage
+        mailbox.Mailbox.__init__(self, '', factory, create)
+        self._file = stream
+        self._toc = None
+        self._next_key = 0
+        self._pending = False   # No changes require rewriting the file.
+        self._locked = False
+        self._file_length = None        # Used to record mailbox size
 
-    note: in python 2.6, this can be written:
-    >>> import itertools
-    >>> itertools.combinations([1,2,3], 2)
-    """
-    list = list[:]
-    while len(list) > 1:
-        first = list.pop()
-        for i in list:
-            yield (first, i)
 
 class MBOXImporter(object):
     """import content of a Unix mailbox into cubicweb as Email (and related) objects"""
@@ -64,11 +67,16 @@ class MBOXImporter(object):
         self.skipped.append(messageid)
 
     def import_mbox_stream(self, stream):
-        from mailbox import UnixMailbox as Mailbox
-        from rfc822 import parsedate
-        from logilab.common.umessage import message_from_file
-        for message in sorted(Mailbox(stream, message_from_file),
-                              key=lambda x:parsedate(x['Date'])):
+        self._import(StreamMailbox(stream, message_from_file, create=False))
+
+    def import_mbox(self, path):
+        self._import(mailbox.mbox(path, message_from_file, create=False))
+
+    def import_maildir(self, path):
+        self._import(mailbox.Maildir(path, message_from_file, create=False))
+
+    def _import(self, mailbox):
+        for message in sorted(mailbox, key=lambda x:parsedate(x['Date'])):
             try:
                 self.import_message(message)
                 if self.autocommit:
@@ -151,7 +159,7 @@ class MBOXImporter(object):
                 self.import_message_parts(part, emaileid)
             if self._context == 'alternative':
                 alternatives = self._alternatives.pop()
-                for eid1, eid2 in combinaison(alternatives):
+                for eid1, eid2 in combinations(alternatives, 2):
                     self.execute('SET X alternative Y WHERE X eid %(x)s, Y eid %(y)s',
                                   {'x': eid1, 'y': eid2})
             self._context = None
